from django.utils.translation import gettext as _

from dynamic_preferences.preferences import Section
from dynamic_preferences.types import BooleanPreference, IntegerPreference, StringPreference

from aleksis.core.registries import site_preferences_registry

matrix = Section("matrix", verbose_name=_("Matrix"))


@site_preferences_registry.register
class Homeserver(StringPreference):
    section = matrix
    name = "homeserver"
    verbose_name = _("URL of Matrix homeserver")
    default = ""


@site_preferences_registry.register
class HomeserverForIDs(StringPreference):
    section = matrix
    name = "homeserver_ids"
    verbose_name = _("Name of Matrix homeserver used for auto-generating Matrix IDs")
    help_text = _("Leave empty to not create Matrix IDs automatically")
    default = ""


@site_preferences_registry.register
class AccessToken(StringPreference):
    section = matrix
    name = "access_token"
    verbose_name = _("Access token to access homeserver")
    default = ""


@site_preferences_registry.register
class DisambiguateRoomAliases(BooleanPreference):
    section = matrix
    name = "disambiguate_room_aliases"
    verbose_name = _("Disambiguate room aliases")
    default = True


@site_preferences_registry.register
class UseSpaces(BooleanPreference):
    section = matrix
    name = "use_spaces"
    verbose_name = _("Use Matrix spaces")
    default = True


@site_preferences_registry.register
class ReducePowerLevels(BooleanPreference):
    section = matrix
    name = "reduce_power_levels"
    verbose_name = _("Reduce existing power levels")
    default = False


@site_preferences_registry.register
class PowerLevelForOwners(IntegerPreference):
    section = matrix
    name = "power_level_for_owners"
    verbose_name = _("Power level for owners")
    default = 50
    required = True


@site_preferences_registry.register
class PowerLevelForMembers(IntegerPreference):
    section = matrix
    name = "power_level_for_members"
    verbose_name = _("Power level for members")
    default = 0
    required = True
